@@ -19,8 +19,8 @@
 
 
 #include "k3b_export.h"
-#include <QtCore/QList>
-#include <QtWidgets/QDialog>
+#include <QList>
+#include <QDialog>
 
 namespace K3b {
     namespace Device {
@@ -33,7 +33,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        DeviceSelectionDialog( QWidget* parent = 0,
+        explicit DeviceSelectionDialog( QWidget* parent = 0,
                                const QString& text = QString() );
         ~DeviceSelectionDialog();
 
